@@ -238,6 +238,9 @@ class ColemenDatabase:
         if len(statements) == 1:
             self.execute_single_statement(sql, args)
 
+    def close(self):
+        self.con.close()
+
     def execute_single_statement(self, sql, args=False):
         '''
             Executes a single SQL query on the database.
